"""Helpers for character notifications."""


import enum


class NotificationTypeEnum(enum.Enum):
    """Maps notification type IDs to names."""

    OldLscMessages = 1
    CharTerminationMsg = 2
    CharMedalMsg = 3
    AllMaintenanceBillMsg = 4
    AllWarDeclaredMsg = 5
    AllWarSurrenderMsg = 6
    AllWarRetractedMsg = 7
    AllWarInvalidatedMsg = 8
    CorpAllBillMsg = 10
    BillOutOfMoneyMsg = 11
    BillPaidCorpAllMsg = 13
    BountyClaimMsg = 14
    CloneActivationMsg = 15
    CorpAppNewMsg = 16
    CorpAppRejectMsg = 17
    CorpAppAcceptMsg = 18
    CorpTaxChangeMsg = 19
    CorpNewsMsg = 20
    CharLeftCorpMsg = 21
    CorpNewCEOMsg = 22
    CorpDividendMsg = 23
    CorpVoteMsg = 25
    CorpVoteCEORevokedMsg = 26
    CorpWarDeclaredMsg = 27
    CorpWarFightingLegalMsg = 28
    CorpWarSurrenderMsg = 29
    CorpWarRetractedMsg = 30
    CorpWarInvalidatedMsg = 31
    ContainerPasswordMsg = 32
    CustomsMsg = 33
    InsuranceFirstShipMsg = 34
    InsurancePayoutMsg = 35
    InsuranceInvalidatedMsg = 36
    SovCorpClaimFailMsg = 38
    SovCorpBillLateMsg = 40
    SovAllClaimLostMsg = 41
    SovAllClaimAquiredMsg = 43
    AllAnchoringMsg = 45
    AllStructVulnerableMsg = 46
    AllStrucInvulnerableMsg = 47
    SovDisruptorMsg = 48
    CorpStructLostMsg = 49
    CorpOfficeExpirationMsg = 50
    CloneRevokedMsg1 = 51
    CloneMovedMsg = 52
    CloneRevokedMsg2 = 53
    InsuranceExpirationMsg = 54
    InsuranceIssuedMsg = 55
    JumpCloneDeletedMsg1 = 56
    JumpCloneDeletedMsg2 = 57
    FWCorpJoinMsg = 58
    FWCorpLeaveMsg = 59
    FWCorpKickMsg = 60
    FWCharKickMsg = 61
    FWCorpWarningMsg = 62
    FWCharWarningMsg = 63
    FWCharRankLossMsg = 64
    FWCharRankGainMsg = 65
    TransactionReversalMsg = 67
    ReimbursementMsg = 68
    LocateCharMsg = 69
    ResearchMissionAvailableMsg = 70
    MissionOfferExpirationMsg = 71
    MissionTimeoutMsg = 72
    StoryLineMissionAvailableMsg = 73
    TutorialMsg = 74
    TowerAlertMsg = 75
    TowerResourceAlertMsg = 76
    StationAggressionMsg1 = 77
    StationStateChangeMsg = 78
    StationConquerMsg = 79
    StationAggressionMsg2 = 80
    FacWarCorpJoinRequestMsg = 81
    FacWarCorpLeaveRequestMsg = 82
    FacWarCorpJoinWithdrawMsg = 83
    FacWarCorpLeaveWithdrawMsg = 84
    CorpLiquidationMsg = 85
    SovereigntyTCUDamageMsg = 86
    SovereigntySBUDamageMsg = 87
    SovereigntyIHDamageMsg = 88
    ContactAdd = 89
    ContactEdit = 90
    IncursionCompletedMsg = 91
    CorpKicked = 92
    OrbitalAttacked = 93
    OrbitalReinforced = 94
    OwnershipTransferred = 95
    FWAllianceWarningMsg = 96
    FWAllianceKickMsg = 97
    AllWarCorpJoinedAllianceMsg = 98
    AllyJoinedWarDefenderMsg = 99
    AllyJoinedWarAggressorMsg = 100
    AllyJoinedWarAllyMsg = 101
    MercOfferedNegotiationMsg = 102
    WarSurrenderOfferMsg = 103
    WarSurrenderDeclinedMsg = 104
    FacWarLPPayoutKill = 105
    FacWarLPPayoutEvent = 106
    FacWarLPDisqualifiedEvent = 107
    FacWarLPDisqualifiedKill = 108
    AllyContractCancelled = 109
    WarAllyOfferDeclinedMsg = 110
    BountyYourBountyClaimed = 111
    BountyPlacedChar = 112
    BountyPlacedCorp = 113
    BountyPlacedAlliance = 114
    KillRightAvailable = 115
    KillRightAvailableOpen = 116
    KillRightEarned = 117
    KillRightUsed = 118
    KillRightUnavailable = 119
    KillRightUnavailableOpen = 120
    DeclareWar = 121
    OfferedSurrender = 122
    AcceptedSurrender = 123
    MadeWarMutual = 124
    RetractsWar = 125
    OfferedToAlly = 126
    AcceptedAlly = 127
    CharAppAcceptMsg = 128
    CharAppRejectMsg = 129
    CharAppWithdrawMsg = 130
    DustAppAcceptedMsg = 131
    DistrictAttacked = 132
    BattlePunishFriendlyFire = 133
    BountyESSTaken = 134
    BountyESSShared = 135
    IndustryTeamAuctionWon = 136
    IndustryTeamAuctionLost = 137
    CloneActivationMsg2 = 138
    CorpAppInvitedMsg = 139
    KillReportVictim = 140
    KillReportFinalBlow = 141
    CorpAppRejectCustomMsg = 142
    CorpFriendlyFireEnableTimerStarted = 143  # pylint: disable=invalid-name
    CorpFriendlyFireDisableTimerStarted = 144  # pylint: disable=invalid-name
    CorpFriendlyFireEnableTimerCompleted = 145  # pylint: disable=invalid-name
    CorpFriendlyFireDisableTimerCompleted = 146  # pylint: disable=invalid-name
    EntosisCaptureStarted = 147
    StationServiceEnabled = 148
    StationServiceDisabled = 149
    InfrastructureHubBillAboutToExpire = 152  # pylint: disable=invalid-name
    SovStructureReinforced = 160
    SovCommandNodeEventStarted = 161
    SovStructureDestroyed = 162
    SovStationEnteredFreeport = 163
    IHubDestroyedByBillFailure = 164
    AllianceCapitalChanged = 165
    BuddyConnectContactAdd = 166
    SovStructureSelfDestructRequested = 167  # pylint: disable=invalid-name
    SovStructureSelfDestructCancel = 168
    SovStructureSelfDestructFinished = 169  # pylint: disable=invalid-name
    StructureFuelAlert = 181
    StructureAnchoring = 182
    StructureUnanchoring = 183
    StructureUnderAttack = 184
    StructureOnline = 185
    StructureLostShields = 186
    StructureLostArmor = 187
    StructureDestroyed = 188
    StructureServicesOffline = 198
    StructureItemsDelivered = 199
    SeasonalChallengeCompleted = 200
    StructureCourierContractChanged = 201
    OperationFinished = 1012
    GiftReceived = 1022
    GameTimeReceived = 1030
    GameTimeSent = 1031
    GameTimeAdded = 1032
    NPCStandingsLost = 3001
    NPCStandingsGained = 3002
    notificationTypeMoonminingExtractionStarted = 202  # noqa pylint: disable=invalid-name
    MoonminingExtractionCancelled = 203
    MoonminingExtractionFinished = 204
    MoonminingLaserFired = 205
    MoonminingAutomaticFracture = 206
